@@ -1,12 +1,12 @@
 #' @importFrom utils chooseCRANmirror
 #' @keywords internal
 getCRANrepos <- function(repos = NULL) {
-  if (is.null(repos)) {
+  if (isNonRepo(repos)) {
     repos <- getOption("repos")["CRAN"]
   }
 
-  # still might be imprecise repository, specifically ""
-  if (isTRUE("" == repos) || is.na(repos)) {
+  # still might be imprecise repository
+  if (isNonRepo(repos)) {
     repos <- "@CRAN@"
   }
 
@@ -14,16 +14,17 @@ getCRANrepos <- function(repos = NULL) {
   if (isTRUE("@CRAN@" %in% repos)) {
     cranRepo <- Sys.getenv("CRAN_REPO")
     repos <- if (nzchar(cranRepo)) {
+      options("repos" = c("CRAN" = cranRepo))
       cranRepo
     } else {
       if (isInteractive()) {
         chooseCRANmirror2() ## sets repo option
-        getOption("repos")["CRAN"]
       } else {
-        "https://cloud.r-project.org"
+        chooseCRANmirror(ind = 1)
       }
+      getOption("repos")["CRAN"]
     }
-    if (is.na(repos)) {
+    if (isTRUE("" == repos) || isTRUE(is.na(repos))) {
       warning("Please choose a valid CRAN repo")
       repos <- getCRANrepos(repos)
     }
@@ -44,3 +45,7 @@ chooseCRANmirror2 <- function(...) {
 }
 
 isInteractive <- function() interactive()
+
+isNonRepo <- function(repos) {
+  (is.null(repos) || isTRUE("" == repos) || isTRUE(is.na(repos)) || is.logical(repos))
+}
