@@ -20,7 +20,7 @@
 #'       is to have packages not be cached locally so each install of the same version will
 #'       be from the original source, e.g., CRAN, GitHub.
 #'   }
-#'   \item{\code{buildBinarieis}}{
+#'   \item{\code{buildBinaries}}{
 #'     Default: \code{TRUE}. Only relevant on *nix systems and if
 #'     \code{getOption("Require.RPackageCache")} is set to a  path. If \code{TRUE}, then
 #'        \code{Require} will pass \code{INSTALL_OPTS = "--build"}, meaning the
@@ -41,6 +41,12 @@
 #'     automatically be deleted after (by default) 1 hour (set via 
 #'     \code{R_AVAILABLE_PACKAGES_CACHE_CONTROL_MAX_AGE} environment variable in seconds)
 #'   }
+#'   \item{\code{setupVerbose}}{
+#'     Default: \code{TRUE}. Logical. Once \code{setup} is called, there are several important
+#'     changes that are made to the user's experience. For beginners with \code{Require},
+#'     the messages that are written are important to see. However, these can be turned off
+#'     setting this to \code{FALSE}
+#'   }
 #'   \item{\code{unloadNamespaces}}{
 #'     Default: \code{TRUE}. (ADVANCED USE) \code{Require} will attempt to detach and unload
 #'     packages that conflict with the requested package installing via \code{Require}.
@@ -61,8 +67,18 @@
 RequireOptions <- function() {
   list(Require.buildBinaries = TRUE,
        Require.persistentPkgEnv = FALSE, # TRUE
+       Require.RPackageFolders = NULL, #"~/._RPackageCache", # nolint
        Require.RPackageCache = NULL, #"~/._RPackageCache", # nolint
+       Require.setupVerbose = TRUE,
+       Require.standAlone = TRUE, 
        Require.unloadNamespaces = TRUE,
+       Require.updateRprofile = FALSE,
+       # Require.useCranCache = NULL,
        Require.verbose = 0
   )
 }
+
+#   \item{\code{useCranCache}}{
+#     Default: \code{NULL}. Experimental. If \code{TRUE}, a user can try 
+#     to use the same cache folder as the crancache package (for binaries only). .
+#   }
